@@ -1,5 +1,6 @@
 "ordicluster" <-
-    function (ord, cluster, prune=0, display="sites", w = weights(ord, display),  ...) 
+    function (ord, cluster, prune=0, display="sites", w = weights(ord, display),
+              ...)
 {
     w <- eval(w)
     mrg <- cluster$merge
@@ -16,7 +17,7 @@
         two <- if (b < 0) ord[-b,] else go[b,]
         n1 <- if (a < 0) n[-a] else n[a]
         n2 <- if (b < 0) n[-b] else n[b]
-        segments(one[1], one[2], two[1], two[2], ...)
+        ordiArgAbsorber(one[1], one[2], two[1], two[2], FUN = segments, ...)
         xm <- weighted.mean(c(one[1],two[1]), w=c(n1,n2))
         ym <- weighted.mean(c(one[2],two[2]), w=c(n1,n2))
         go[i,] <- c(xm,ym)
