@@ -1,24 +1,24 @@
 "ordiellipse" <-
-    function (ord, groups, display = "sites", kind = c("sd", "se"), 
-              conf, draw = c("lines", "polygon"), w = weights(ord, display), 
-              show.groups, ...) 
+    function (ord, groups, display = "sites", kind = c("sd", "se"),
+              conf, draw = c("lines", "polygon"), w = weights(ord, display),
+              show.groups, ...)
 {
-    if (!require(ellipse)) 
+    if (!require(ellipse))
         stop("Requires package `ellipse' (from CRAN)")
     kind <- match.arg(kind)
     draw <- match.arg(draw)
     pts <- scores(ord, display = display, ...)
     w <- eval(w)
-    if (length(w) == 1) 
+    if (length(w) == 1)
         w <- rep(1, nrow(pts))
-    if (is.null(w)) 
+    if (is.null(w))
         w <- rep(1, nrow(pts))
      if (!missing(show.groups)) {
         take <- groups %in% show.groups
         pts <- pts[take, , drop = FALSE]
         groups <- groups[take]
         w <- w[take]
-    }   
+    }
     out <- seq(along = groups)
     inds <- names(table(groups))
     for (is in inds) {
@@ -27,18 +27,19 @@
             X <- pts[gr, ]
             W <- w[gr]
             mat <- cov.wt(X, W)
-            if (kind == "se") 
+            if (kind == "se")
                 mat$cov <- mat$cov/mat$n.obs
-            if (missing(conf)) 
+            if (missing(conf))
                 t <- 1
             else t <- sqrt(qchisq(conf, 2))
-            if (draw == "lines") 
-                lines(ellipse(mat$cov, centre = mat$center, t = t), 
-                      ...)
+            if (draw == "lines")
+                ordiArgAbsorber(ellipse(mat$cov, centre = mat$center, t = t),
+                      FUN = lines, ...)
             else {
                 xy <- ellipse(mat$cov, center = mat$center, t = t)
-                polygon(xy[, 1] + mat$center[1], xy[, 2] + mat$center[2], 
-                        ...)
+                ordiArgAbsorber(xy[, 1] + mat$center[1],
+                                xy[, 2] + mat$center[2],
+                                FUN = polygon, ...)
             }
         }
     }
