@@ -1,6 +1,6 @@
 "ordispider" <-
-    function (ord, groups, display = "sites", w = weights(ord, display), 
-              show.groups, ...) 
+    function (ord, groups, display = "sites", w = weights(ord, display),
+              show.groups, ...)
 {
     if (inherits(ord, "cca") && missing(groups)) {
         lc <- scores(ord, display = "lc", ...)
@@ -10,9 +10,9 @@
     }
     pts <- scores(ord, display = display, ...)
     w <- eval(w)
-    if (length(w) == 1) 
+    if (length(w) == 1)
         w <- rep(1, nrow(pts))
-    if (is.null(w)) 
+    if (is.null(w))
         w <- rep(1, nrow(pts))
     if (!missing(show.groups)) {
         take <- groups %in% show.groups
@@ -28,7 +28,8 @@
             X <- pts[gr, ]
             W <- w[gr]
             ave <- apply(X, 2, weighted.mean, w = W)
-            segments(ave[1], ave[2], X[, 1], X[, 2], ...)
+            ordiArgAbsorber(ave[1], ave[2], X[, 1], X[, 2],
+                            FUN = segments, ...)
         }
     }
     invisible()
